![OctoAPI Logo](docs/_static/logo.png)

[![Coverage Status](https://coveralls.io/repos/github/jemrobinson/octoapi/badge.svg?branch=main)](https://coveralls.io/github/jemrobinson/octoapi?branch=main)
[![Dependabot](https://flat.badgen.net/dependabot/jemrobinson/octoapi?icon=dependabot)](https://dependabot.com/)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Licence: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)

[![Build Status](https://travis-ci.com/jemrobinson/octoapi.svg?branch=main)](https://travis-ci.com/jemrobinson/octoapi)
![OSX](https://img.shields.io/badge/-555?&logo=apple&logoColor=white)[![Build Status](https://badges.formidable.com/travis.com/jemrobinson/octoapi?branch=main&env=OSBADGE=osx&label=%20)](https://travis-ci.com/github/jemrobinson/octoapi)
![Linux](https://img.shields.io/badge/-555?&logo=linux&logoColor=white)[![Build Status](https://badges.formidable.com/travis.com/jemrobinson/octoapi?branch=main&env=OSBADGE=linux&label=%20)](https://travis-ci.com/github/jemrobinson/octoapi)
![Windows](https://img.shields.io/badge/-555?&logo=windows&logoColor=white)[![Build Status](https://badges.formidable.com/travis.com/jemrobinson/octoapi?branch=main&env=OSBADGE=windows&label=%20)](https://travis-ci.com/github/jemrobinson/octoapi)

## OctoAPI
This package provides a Python interface to the [Octopus Energy API](https://developer.octopus.energy/docs/api/).

#### Dependencies
- `Python >= 3.6`

#### Install
WIP
<!-- Install with `pip` using

```bash
pip install octoapi
``` -->

#### Deploy
WIP

#### Testing
The automated tests can be run using

```bash
pytest
```

## Contribute
Please look at [our contributing guidelines](CONTRIBUTING.md) if you want to contribute to this project. GitHub also has some good guides on [how to contribute](https://guides.github.com/activities/contributing-to-open-source/#contributing).

## License
This project uses a [GPL v3 licence](LICENSE).
